@@ -19,16 +19,21 @@ DOCKER_BUILDKIT=1 docker build -t "$DOCKER_IMAGE_NAME" --build-arg "UID=$(id -u)
 
 # by default, run tox
 RUN_JOB=${RUN_JOB:-tox}
-
 case $RUN_JOB in
     tox)
         # execute tox in the docker container. don't run in parallel; the test
         # script writes files to an in-tree location, so run serially to avoid
         # clobbering during the tests
-        docker run --rm -v "$(pwd)":/mnt/workspace -t "$DOCKER_IMAGE_NAME" bash -c "tox $TOX_ARGS"
+        docker run --rm -v "$(pwd)":/workspace -t "$DOCKER_IMAGE_NAME" bash -c "tox $TOX_ARGS"
+
+        ./tools/test-nonexistent-file-cmd.sh
+    ;;
+    quick-test)
+        # single quick test
+        docker run --rm -v "$(pwd)":/workspace -t "$DOCKER_IMAGE_NAME" bash -c "python3 tests/compare.py"
     ;;
     rst2man)
         # build man page from README
-        docker run --rm -v "$(pwd)":/mnt/workspace -t "$DOCKER_IMAGE_NAME" bash gen-manpage.sh README dtrx.1
+        docker run --rm -v "$(pwd)":/workspace -t "$DOCKER_IMAGE_NAME" bash tools/gen-manpage.sh archived/README dtrx.1
     ;;
 esac
